==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Dữ liệu liên hệ cơ quan"

, "Organisation / Unit"
: "Tổ chức/ đơn vị"

, "Business Address"
: "Địa chỉ cơ quan"

, "Email"
: "Email"

, "Telephone Work"
: "Điện thoại cơ quan"

, "Telephone Cellphone"
: "Số điện thoại cầm tay"

, "Telephone Car"
: "Điện thoại trên xe"

, "Telephone Fax"
: "Số fax"

, "Telephone Page"
: "Trang điện thoại"

, "URL"
: "URL"

, "Role"
: "Vai trò"

, "Room"
: "Phòng"

, "Assistant"
: "Trợ lý"

, "Assistant Telephone"
: "Số điện thoại trợ lý"

, "Private Contact Data"
: "Dữ liệu liên hệ mật"

, "Private Address"
: "Địa chỉ nhà riêng"

, "Email Home"
: "Email nhà riêng"

, "Telephone Home"
: "Điện thoại nhà riêng"

, "Telephone Cellphone Private"
: "Số di động riêng"

, "Telephone Fax Home"
: "Số fax nhà riêng"

, "URL Home"
: "Địa chỉ website"

, "Other Data"
: "Dữ liệu khác"

, "Birthday"
: "Ngày sinh"

, "Job Title"
: "Chức danh"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "one: Danh sách\nother: Danh sách"

]
, "Percent"
: ""

, "Description"
: "Mô tả"

, "Members"
: ""

, "Type"
: "Kiểu"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "one: Sổ địa chỉ\nother: Sổ địa chỉ"

]
, "Contact, Contacts"
: [
  "one: Liên hệ\nother: Liên hệ"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Quốc gia"

, "City"
: "Thành phố"

, "Postalcode"
: "Mã vùng"

, "Region"
: "Miền"

, "Street"
: "Phố"

, "Street 2"
: "Phố 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Quốc gia (riêng tư)"

, "City (private)"
: "Thành phố (riêng tư)"

, "Postalcode (private)"
: "Mã vùng (riêng tư)"

, "Region (private)"
: "Vùng (riêng tư)"

, "Street (private)"
: "Phố (riêng tư)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (riêng tư)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""

]
, "Note"
: "Ghi chép"

, "Last Name"
: "Tên"

, "Display Name"
: "Tên hiển thị"

, "Full Name"
: "Tên đầy đủ"

, "First Name"
: "Họ"

, "Middle Name"
: "Đệm"

, "Title"
: "Tiêu đề"

, "Suffix"
: "Hậu tố"

, "Company"
: "Công ty"

, "Unit"
: "Đơn vị"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Vai trò công việc"

, "Salutation"
: "Lời chào"

, "syncBackendIds"
: ""

, "Car phone"
: "Điện thoại trên xe"

, "Mobile"
: "Di động"

, "Mobile (private)"
: "Di động (cá nhân)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (cá nhân)"

, "Phone (private)"
: "Điện thoại (cá nhân)"

, "Pager"
: "Phân trang"

, "Phone"
: "Điện thoại"

, "Timezone"
: "Múi giờ"

, "Web"
: "Web"

, "URL (private)"
: "URL (riêng tư)"

, "Label"
: ""

, "Lists"
: "Danh sách"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Thông tin liên hệ"

, "Company Address"
: "Địa chỉ công ty"

, "New Contact"
: "Thêm liên lạc"

, "ID"
: ""

, "Name"
: "Tên"

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Import contacts"
: "Nhập liên lạc"

, "Contact of a user account"
: "Thông tin liên lạc của 1 tài khoản"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Riêng tư"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Thẻ"

, "List Roles"
: ""

, "Street (Company Address)"
: "Phố (Địa chỉ cơ quan)"

, "Street 2 (Company Address)"
: "Phố 2"

, "City (Company Address)"
: "Thành phố (Công ty)"

, "Region (Company Address)"
: "Vùng (Công ty)"

, "Postal Code (Company Address)"
: "Mã vùng (Công ty)"

, "Country (Company Address)"
: "Quốc gia (Công ty)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Phố (Địa chỉ riêng)"

, "Street 2 (Private Address)"
: "Phố 2(Địa chỉ riêng)"

, "City (Private Address)"
: "Thành phố (Địa chỉ riêng)"

, "Region (Private Address)"
: "Vùng (Địa chỉ riêng)"

, "Postal Code (Private Address)"
: "Mã vùng (Địa chỉ riêng)"

, "Country (Private Address)"
: "Quốc gia (Địa chỉ riêng)"

, "Company Communication"
: "Truyền thông công ty"

, "Private Communication"
: "Truyền thông cá nhân"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (cá nhân)"

, "Web (private)"
: "Web (riêng tư)"

, "Contacts"
: "Liên lạc"

, "Addressbooks"
: "Sổ địa chỉ"

, "User Account"
: "Tài khoản người dùng"

, "Quick Search"
: "Tìm nhanh"

, "Postal Code"
: "Mã vùng"

, "Last Modified Time"
: "Thời gian sửa lần cuối"

, "Last Modified By"
: "Sửa lần cuối bởi"

, "Creation Time"
: "Thời giao tạo"

, "Created By"
: "Tạo bởi"

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Nhập mô tả"

, "{0} must be given"
: ""

, "Member of List"
: "Thành viên của danh sách"

, "Map"
: "Bản đồ"

, "Company address"
: "Địa chỉ cơ quan"

, "Private address"
: "Địa chỉ nhà riêng"

, "CardDAV URL"
: "URL CardDAV"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Thông tin cá nhân"

, "Parse address"
: "Địa chỉ"

, "Print contact"
: ""

, "Paste address"
: "Dán địa chỉ"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Kết thúc chế độ token"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Mọi liên hệ"

, "Default Addressbook"
: "Sổ địa chỉ mặc đ"

, "The default addressbook for new contacts"
: "Sổ địa chỉ mặc định cho liên hệ mới"

, "Default Favorite"
: "Lối tắt mặc định"

, "The default favorite which is loaded on addressbook startup"
: "Lối tắt mặc định sẽ được nạp khi sổ địa chỉ khởi động"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: "Mọi liên hệ"

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Contact duplicate check fields"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Các trường này sẽ được kiểm tra khi 1 địa chỉ mới được tạo. Nếu 1 biểu ghi với dữ liệu tương tự trong các trường này được tìm thấy, tính năng chống trùng lặp sẽ được thực hiện."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Lời chào liên hệ sẵn có "

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Lời chào liên hệ có thể. Xin nhớ rằng giá trị mở rộng có thể ảnh hưởng tới hệ thống sổ địa chỉ trong việc xuất hoặc đồng bộ dữ liệu. "

, "Mr"
: "Ông"

, "Ms"
: "Cô"

, "Parsing rules for addresses"
: "Quy tắc phân loại cho địa chỉ"

, "Path to a XML file with address parsing rules."
: "Đường dẫn tới file XML với quy tắc phân loại địa chỉ"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Nhập dữ liệu liên hệ VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Nhập danh sách (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Liên lạc đã được nhập vào ###CURRENTDATE### lúc ###CURRENTTIME### bởi ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 German"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Nhập dữ liệu CSV từ Outlook address book"

, "Contact CSV import from mac address book"
: "Nhập dữ liệu liên hệ CSV từ sổ địa chỉ Mac"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Nhập dữ liệu từ sổ địa chỉ google"

, "manage shared addressbooks"
: "quản lý sổ địa chỉ dùng chung"

, "Create new shared addressbook folders"
: "Tạo thư mục sổ địa chỉ dùng chung"

, "manage shared addressbook favorites"
: "quản lý lối tắt dùng chung"

, "Create or update shared addressbook favorites"
: "Tạo, cập nhật lối tắt dùng chung"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""

]
, "%s's personal addressbook"
: "sổ địa chỉ cá nhân của %s"

, "All contacts I have read grants for"
: "Mọi liên hệ tôi đã đọc quyền cho"

, "My company"
: "Công ty tôi"

, "All coworkers in my company"
: "Tất cả đồng nghiệp trong công ty tôi"

, "My contacts"
: "Liên hệ của tôi"

, "All contacts in my Addressbooks"
: "Mọi liên hệ trong sổ địa chỉ của tôi"

, "Last modified by me"
: "Sửa lần cuối bởi tôi"

, "All contacts that I have last modified"
: "Mọi liên hệ tôi đã sửa gần đây"

, "Internal Contacts"
: "Liên hệ nội bộ"

, "List"
: "one: Danh sách\nother: Danh sách"

, "Addressbook"
: "one: Sổ địa chỉ\nother: Sổ địa chỉ"

, "Contact"
: "one: Liên hệ\nother: Liên hệ"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Bản đồ"

, "Preferred Address"
: ""

, "Personal Information"
: "Thông tin cá nhân"

, "Salutation"
: "Lời chào"

, "Title"
: "Tiêu đề"

, "Short Name"
: ""

, "First Name"
: "Họ"

, "Middle Name"
: "Đệm"

, "Last Name"
: "Tên"

, "Company"
: "Công ty"

, "Unit"
: "Đơn vị"

, "Display Name"
: "Tên hiển thị"

, "Industry, Industries"
: [
  ""

]
, "Job Title"
: "Chức danh"

, "Birthday (private)"
: ""

, "Contact Information"
: "Thông tin liên hệ"

, "Phone"
: "Điện thoại"

, "Mobile"
: "Di động"

, "Fax"
: "Fax"

, "Phone (private)"
: "Điện thoại (cá nhân)"

, "Mobile (private)"
: "Di động (cá nhân)"

, "Fax (private)"
: "Fax (cá nhân)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (cá nhân)"

, "Web"
: "Web"

, "Company Address"
: "Địa chỉ công ty"

, "Street"
: "Phố"

, "Street 2"
: "Phố 2"

, "Region"
: "Miền"

, "Postal Code"
: "Mã vùng"

, "City"
: "Thành phố"

, "Country"
: "Quốc gia"

, "Private Address"
: "Địa chỉ nhà riêng"

, "Description"
: "Mô tả"

, "Enter description"
: "Nhập mô tả"

, "Groups"
: ""

, "Parse address"
: "Địa chỉ"

, "Print contact"
: ""

, "Paste address"
: "Dán địa chỉ"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Kết thúc chế độ token"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "one: Liên hệ\nother: Liên hệ"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "URL CardDAV"

, "New Contact"
: "Thêm liên lạc"

, "Addressbook, Addressbooks"
: [
  "one: Sổ địa chỉ\nother: Sổ địa chỉ"

]
, "ID"
: ""

, "Name"
: "Tên"

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Private"
: "Riêng tư"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""

]
, "List Personal Grant, List Personal Grants"
: [
  ""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Hậu tố"

, "Birthday"
: "Ngày sinh"

, "Job Role"
: "Vai trò công việc"

, "Room"
: "Phòng"

, "Street (Company Address)"
: "Phố (Địa chỉ cơ quan)"

, "Street 2 (Company Address)"
: "Phố 2"

, "City (Company Address)"
: "Thành phố (Công ty)"

, "Region (Company Address)"
: "Vùng (Công ty)"

, "Postal Code (Company Address)"
: "Mã vùng (Công ty)"

, "Country (Company Address)"
: "Quốc gia (Công ty)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Phố (Địa chỉ riêng)"

, "Street 2 (Private Address)"
: "Phố 2(Địa chỉ riêng)"

, "City (Private Address)"
: "Thành phố (Địa chỉ riêng)"

, "Region (Private Address)"
: "Vùng (Địa chỉ riêng)"

, "Postal Code (Private Address)"
: "Mã vùng (Địa chỉ riêng)"

, "Country (Private Address)"
: "Quốc gia (Địa chỉ riêng)"

, "Company Communication"
: "Truyền thông công ty"

, "Private Communication"
: "Truyền thông cá nhân"

, "Web (private)"
: "Web (riêng tư)"

, "Contacts"
: "Liên lạc"

, "Addressbooks"
: "Sổ địa chỉ"

, "User Account"
: "Tài khoản người dùng"

, "Quick Search"
: "Tìm nhanh"

, "Type"
: "Kiểu"

, "Last Modified Time"
: "Thời gian sửa lần cuối"

, "Last Modified By"
: "Sửa lần cuối bởi"

, "Creation Time"
: "Thời giao tạo"

, "Created By"
: "Tạo bởi"

, "List, Lists"
: [
  "one: Danh sách\nother: Danh sách"

]
, "Lists"
: "Danh sách"

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Nhập liên lạc"

, "Contact of a user account"
: "Thông tin liên lạc của 1 tài khoản"

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Thẻ"

, "Full Name"
: "Tên đầy đủ"

, "Postalcode"
: "Mã vùng"

, "Street (private)"
: "Phố (riêng tư)"

, "City (private)"
: "Thành phố (riêng tư)"

, "Region (private)"
: "Vùng (riêng tư)"

, "Postalcode (private)"
: "Mã vùng (riêng tư)"

, "Country (private)"
: "Quốc gia (riêng tư)"

, "Email"
: "Email"

, "Car phone"
: "Điện thoại trên xe"

, "Pager"
: "Phân trang"

, "Email (private)"
: "Email (riêng tư)"

, "URL (private)"
: "URL (riêng tư)"

, "Note"
: "Ghi chép"

, "Timezone"
: "Múi giờ"

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Địa chỉ cơ quan"

, "Private address"
: "Địa chỉ nhà riêng"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Mọi liên hệ"

, "Default Addressbook"
: "Sổ địa chỉ mặc đ"

, "The default addressbook for new contacts"
: "Sổ địa chỉ mặc định cho liên hệ mới"

, "Default Favorite"
: "Lối tắt mặc định"

, "The default favorite which is loaded on addressbook startup"
: "Lối tắt mặc định sẽ được nạp khi sổ địa chỉ khởi động"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Contact duplicate check fields"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Các trường này sẽ được kiểm tra khi 1 địa chỉ mới được tạo. Nếu 1 biểu ghi với dữ liệu tương tự trong các trường này được tìm thấy, tính năng chống trùng lặp sẽ được thực hiện."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Lời chào liên hệ sẵn có "

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Lời chào liên hệ có thể. Xin nhớ rằng giá trị mở rộng có thể ảnh hưởng tới hệ thống sổ địa chỉ trong việc xuất hoặc đồng bộ dữ liệu. "

, "Mr"
: "Ông"

, "Ms"
: "Cô"

, "Parsing rules for addresses"
: "Quy tắc phân loại cho địa chỉ"

, "Path to a XML file with address parsing rules."
: "Đường dẫn tới file XML với quy tắc phân loại địa chỉ"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "sổ địa chỉ cá nhân của %s"

, "Business Contact Data"
: "Dữ liệu liên hệ cơ quan"

, "Organisation / Unit"
: "Tổ chức/ đơn vị"

, "Business Address"
: "Địa chỉ cơ quan"

, "Telephone Work"
: "Điện thoại cơ quan"

, "Telephone Cellphone"
: "Số điện thoại cầm tay"

, "Telephone Car"
: "Điện thoại trên xe"

, "Telephone Fax"
: "Số fax"

, "Telephone Page"
: "Trang điện thoại"

, "URL"
: "URL"

, "Role"
: "Vai trò"

, "Assistant"
: "Trợ lý"

, "Assistant Telephone"
: "Số điện thoại trợ lý"

, "Private Contact Data"
: "Dữ liệu liên hệ mật"

, "Email Home"
: "Email nhà riêng"

, "Telephone Home"
: "Điện thoại nhà riêng"

, "Telephone Cellphone Private"
: "Số di động riêng"

, "Telephone Fax Home"
: "Số fax nhà riêng"

, "URL Home"
: "Địa chỉ website"

, "Other Data"
: "Dữ liệu khác"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Nhập dữ liệu CSV từ Outlook address book"

, "Contact CSV import from mac address book"
: "Nhập dữ liệu liên hệ CSV từ sổ địa chỉ Mac"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 German"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Nhập dữ liệu liên hệ VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Nhập danh sách (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Liên lạc đã được nhập vào ###CURRENTDATE### lúc ###CURRENTTIME### bởi ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Nhập dữ liệu từ sổ địa chỉ google"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Liên hệ nội bộ"

, "All contacts I have read grants for"
: "Mọi liên hệ tôi đã đọc quyền cho"

, "My company"
: "Công ty tôi"

, "All coworkers in my company"
: "Tất cả đồng nghiệp trong công ty tôi"

, "My contacts"
: "Liên hệ của tôi"

, "All contacts in my Addressbooks"
: "Mọi liên hệ trong sổ địa chỉ của tôi"

, "Last modified by me"
: "Sửa lần cuối bởi tôi"

, "All contacts that I have last modified"
: "Mọi liên hệ tôi đã sửa gần đây"

, "All Contacts"
: "Mọi liên hệ"

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "quản lý sổ địa chỉ dùng chung"

, "Create new shared addressbook folders"
: "Tạo thư mục sổ địa chỉ dùng chung"

, "manage shared addressbook favorites"
: "quản lý lối tắt dùng chung"

, "Create or update shared addressbook favorites"
: "Tạo, cập nhật lối tắt dùng chung"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""


]
, "Industry"
: ""

, "Contact"
: "one: Liên hệ\nother: Liên hệ"

, "Addressbook"
: "one: Sổ địa chỉ\nother: Sổ địa chỉ"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "one: Danh sách\nother: Danh sách"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
